package com.huiju.estateagents.statistic.service.impl;

import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.huiju.estateagents.common.CommConstant;
import com.huiju.estateagents.common.StringUtils;
import com.huiju.estateagents.statistic.entity.TaCustomerStatisticDaily;
import com.huiju.estateagents.statistic.mapper.TaCustomerStatisticDailyMapper;
import com.huiju.estateagents.statistic.service.ITaCustomerStatisticDailyService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 客户分析日统计表 小程序盘客工具客户分析 服务实现类
 * </p>
 *
 * @author jobob
 * @since 2019-11-08
 */
@Service
public class TaCustomerStatisticDailyServiceImpl extends ServiceImpl<TaCustomerStatisticDailyMapper, TaCustomerStatisticDaily> implements ITaCustomerStatisticDailyService {
	
	@Autowired
	private TaCustomerStatisticDailyMapper customerStatisticDailyMapper;
	
	/**
	 * 每天的跟进客户统计
	 *
	 * @param nowDate
	 */
	@Override
	public void followUpStatisticDaily(LocalDateTime nowDate) {
		//按当前时间获取当天的跟进客户的数量，多一个客户进行多次跟进行为，只记录一次
		List<TaCustomerStatisticDaily> list = customerStatisticDailyMapper.getFollowUpData(nowDate);
		//批量保存
		statisticDailySaveBatch(list,nowDate,CommConstant.CUSTOMER_TYPE_FOLLOW);
	}
	
	/**
	 * 每天的新增客户统计
	 *
	 * @param nowDate
	 */
	@Override
	public void newCustomerStatisticDaily(LocalDateTime nowDate) {
		//按当前时间获取当天的新增客户的数量，ta_recommend_customer 表的status 为1 的就是新增客户
		List<TaCustomerStatisticDaily> list = customerStatisticDailyMapper.getNewCustomerData(nowDate,CommConstant.STATUS_NORMAL);
		//批量保存
		statisticDailySaveBatch(list,nowDate,CommConstant.CUSTOMER_TYPE_NEW);
	}
	
	/**
	 * 每天的到访客户统计
	 *
	 * @param nowDate
	 */
	@Override
	public void visiteStatisticDaily(LocalDateTime nowDate) {
		//按当前时间获取当天的到访客户的数量，同一天同一个项目只记录一次
		List<TaCustomerStatisticDaily> list = customerStatisticDailyMapper.getVisiteCustomerData(nowDate,CommConstant.STATUS_NORMAL);
		List<TaCustomerStatisticDaily> saveList = new ArrayList<>();
		list.forEach(e -> {
			if (null != e.getOrgId() && !e.getOrgId().equals("null")){
				saveList.add(e);
			}
		});
		//批量保存
		statisticDailySaveBatch(saveList,nowDate,CommConstant.CUSTOMER_TYPE_VISITE);
	}
	
	/**
	 * 批量保存当天的统计数据
	 * @param list
	 * @param nowDate
	 * @param customerType
	 */
	private void statisticDailySaveBatch(List<TaCustomerStatisticDaily> list, LocalDateTime nowDate, String customerType) {
		list.forEach(e -> {
			e.setCreateDate(nowDate);
			e.setCustomerType(customerType);
		});
		//批量保存
		this.saveBatch(list);
	}
}
